Class: Decidim::Feeds::AdminLog::FeedPresenter

Inherits:
Log::BasePresenter
  • Object
show all
Defined in:
app/presenters/decidim/feeds/admin_log/feed_presenter.rb

Overview

This class holds the logic to present a Decidim::Feeds::Feed for the AdminLog log.

Usage should be automatic and you should not need to call this class directly, but here is an example:

action_log = Decidim::ActionLog.last
view_helpers # => this comes from the views
FeedPresenter.new(action_log, view_helpers).present