Class: Decidim::Feeds::CurrentFeed

Inherits:
Object
  • Object
show all
Defined in:
app/constraints/decidim/feeds/current_feed.rb

Overview

This class infers the current feed we are scoped to by looking at the request parameters and the organization in the request environment, and injects it into the environment.

Instance Method Summary collapse

Instance Method Details

#matches?(request) ⇒ Boolean

Public: Matches the request against a feed and injects it into the environment.

request - The request that holds the feeds relevant information.

Returns a true if the request matched, false otherwise

Returns:

  • (Boolean)


16
17
18
19
20
21
22
23
# File 'app/constraints/decidim/feeds/current_feed.rb', line 16

def matches?(request)
  env = request.env

  @organization = env["decidim.current_organization"]
  return false unless @organization

  current_feed(env, request.params) ? true : false
end