Class: Decidim::Feeds::Engine
- Inherits:
-
Rails::Engine
- Object
- Rails::Engine
- Decidim::Feeds::Engine
- Defined in:
- lib/decidim/feeds/engine.rb
Overview
This is the engine that runs on the public interface of feeds.
This is the engine that runs on the public interface of feeds.