Module: Decidim::Feeds::Admin::Concerns::FeedAdmin
- Extended by:
- ActiveSupport::Concern
- Included in:
- Decidim::Feeds::Admin::ComponentsController
- Defined in:
- app/controllers/decidim/feeds/admin/concerns/feed_admin.rb
Overview
This concern is meant to be included in all controllers that are scoped into a feed's admin panel. It will override the layout so it shows the sidebar, preload the feed, etc.